use {
    crate::prelude::ParseMailboxError,
    std::{fmt, io},
};

#[derive(Debug)]
pub enum Error {
    Io(io::Error),
    MailBox(ParseMailboxError),
    Permissions(pw::Error),
}

impl fmt::Display for Error {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        match self {
            Self::Io(e) => write!(f, "Filesystem error: {e}"),
            Self::MailBox(e) => write!(f, "Filesystem error: {e}"),
            Self::Permissions(e) => write!(f, "Filesystem error: {e}"),
        }
    }
}

impl std::error::Error for Error {
    fn source(&self) -> Option<&(dyn std::error::Error + 'static)> {
        match self {
            Self::Io(e) => Some(e),
            Self::MailBox(e) => Some(e),
            Self::Permissions(e) => Some(e),
        }
    }
}

impl From<io::Error> for Error {
    fn from(value: io::Error) -> Self {
        Self::Io(value)
    }
}

impl From<ParseMailboxError> for Error {
    fn from(value: ParseMailboxError) -> Self {
        Self::MailBox(value)
    }
}

impl From<pw::Error> for Error {
    fn from(value: pw::Error) -> Self {
        Self::Permissions(value)
    }
}
