use super::parser::Mode;
use std::{fmt, num::ParseIntError};

#[derive(Debug)]
pub enum Error {
    ParseInt,
    UnexpectedChar(Mode, char),
    InvalidMonth,
    InvalidDay,
    InvalidHour,
    InvalidMinute,
    InvalidSecond,
    InvalidTimezone,
    InvalidOffset,
    TrailingGarbage,
    Truncated,
    MissingSeparator,
}

impl fmt::Display for Error {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "{self:?}")
    }
}

impl std::error::Error for Error {}

impl From<ParseIntError> for Error {
    fn from(_value: ParseIntError) -> Self {
        Self::ParseInt
    }
}
